@@ -5,7 +5,7 @@ import sqlite3
 
 from multiprocessing import Pool
 from napoleontoolbox.file_saver import dropbox_file_saver
-
+from napoleontoolbox.parallel_run import launcher_utility
 import json
 import math
 
@@ -17,7 +17,9 @@ import random
 import string
 
 class SignalParalleLauncher():
-    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', triggers = [True], transaction_costs = [True], normalizations = [False], signal_idiosyncratic_paramaters=[None], table_max_size = 2000):
+    def __init__(self,starting_date = None, running_date = None, drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',underlying=None,frequence=None,algo=None,db_path_suffix = '_alphas.sqlite', triggers = [True], transaction_costs = [True], normalizations = [False], signal_idiosyncratic_paramaters=[None], table_max_size = 2000):
+        self.starting_date=starting_date
+        self.running_date=running_date
         self.args = []
         self.key_args = []
         self.seed = 0
@@ -42,11 +44,11 @@ class SignalParalleLauncher():
             saving_key, _ = self.create_saving_key(*me_arg)
             self.mapping_keys[saving_key] = self.counter
             self.counter = self.counter + 1
-
         self.run_number = self.counter - 1
         self.local_root_directory = local_root_directory
         self.user = user
         self.db_path_suffix = db_path_suffix
+        self.db_path_name = launcher_utility.get_database_name(user, frequence, underlying, starting_date, running_date, db_path_suffix)
         self.filename =  user + db_path_suffix
         self.db_path = self.local_root_directory + self.filename
         self.runs = []
