@@ -42,10 +42,14 @@ class AbstractRunner(ABC):
         self.saving_return_path = self.local_root_directory+self.underlying+self.freqly_return_pkl_filename_suffix
         self.recompute_all = recompute_all
         self.db_path_suffix = db_path_suffix
+        self.db_path_name = user+'_'+frequence  + '_' + underlying + '_' + starting_date.strftime(
+            '%d_%b_%Y') + '_' + running_date.strftime('%d_%b_%Y') + db_path_suffix
+
+
         if not self.recompute_all:
             saver = signal_result_analyzer.ParallelRunResultAnalyzer(drop_token=drop_token,
                                                                      local_root_directory=local_root_directory, user=user,
-                                                                     db_path_suffix=self.db_path_suffix)
+                                                                     db_path_suffix=self.db_path_name)
             self.precomputed_results_df, self.precomputed_signals_df = saver.analyzeAllRunResults()
         else:
             self.precomputed_results_df, self.precomputed_signals_df  = None, None
